@@ -1,20 +1,9 @@
 /*
-    Copyright 2013 by Reza Fatahilah Shah <rshah0385@kireihana.com>
-    Copyright 2019 Filip Fila <filipfila.kde@gmail.com>
-    Copyright 2020 David Redondo <kde@david-redondo.de>
+    SPDX-FileCopyrightText: 2013 Reza Fatahilah Shah <rshah0385@kireihana.com>
+    SPDX-FileCopyrightText: 2019 Filip Fila <filipfila.kde@gmail.com>
+    SPDX-FileCopyrightText: 2020 David Redondo <kde@david-redondo.de>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "sddmkcm.h"
@@ -253,6 +242,11 @@ void SddmKcm::synchronizeSettings()
         qDebug() << "Cannot find plasmarc file.";
     }
 
+    auto path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kscreen/", QStandardPaths::LocateDirectory);
+    if (!path.isEmpty()) {
+        args[QStringLiteral("kscreen-config")] = path;
+    }
+
     KAuth::Action syncAction(QStringLiteral("org.kde.kcontrol.kcmsddm.sync"));
     syncAction.setHelperId(QStringLiteral("org.kde.kcontrol.kcmsddm"));
     syncAction.setArguments(args);
@@ -268,6 +262,7 @@ void SddmKcm::synchronizeSettings()
             }
         } else {
             qDebug() << "Synchronization successful";
+            Q_EMIT syncSuccessful();
         }
     });
     job->start();
@@ -287,7 +282,7 @@ void SddmKcm::resetSyncronizedSettings()
     // send paths to helper
     QVariantMap args;
 
-    args[QStringLiteral("kde_settings.conf")] = QString{QLatin1String(SDDM_CONFIG_DIR "/") + QStringLiteral("kde_settings.conf")};
+    args[QStringLiteral("kde_settings.conf")] = QStringLiteral(SDDM_CONFIG_DIR "/kde_settings.conf");
 
     args[QStringLiteral("sddm.conf")] = QLatin1String(SDDM_CONFIG_FILE);
 
@@ -315,6 +310,7 @@ void SddmKcm::resetSyncronizedSettings()
             }
         } else {
             qDebug() << "Reset successful";
+            Q_EMIT resetSyncedDataSuccessful();
         }
     });
     job->start();
